"mxphi" <- 
# compute the maximum deflecting angle and the corresponding shock angle
# that separates the weak and strong obliques shocks for a particular value 
# of the Froude number.
function(Fr, method=c("exact","approximate")) {
if (any(Fr<0) || any(Fr>999)) 
   stop("Fr cannot be outside the range [0,999]")
mthd <- switch(match.arg(method), exact = 1, approximate = 2)
if (mthd==1) {
   teta <- rep(NA,length(Fr))
   for (i in seq(along=Fr)) 
      teta[i] <- uniroot(viadam.mxdffn,lower=asin(1/Fr[i]),upper=pi/2-.Machine$double.eps,Fr=Fr[i])$root
   phi <- obliqueshock(teta,Fr)$phi
} else {
   phi <- pi/2 - 2^(3/4)/sqrt(Fr) - 2^(1/4)/6/Fr^1.5
   teta <- obliquenshock(phi,Fr)$teta
}
data.frame(teta=teta,phi=phi)
}

viadam.mxdffn <- 
# function used by mxphi
function(teta,Fr) {
cs <- cos(teta)
sn <- sin(teta)
tn <- tan(teta)
cs2 <- cs^2
sn2 <- sn^2
Fr2sn2 <- Fr^2*sn2
G  <- sqrt(1+8*Fr2sn2)
2*G*(G-1) - 16*cs2*Fr2sn2 - (1+(2*tn/(G-1))^2)*G*(G-1)^2*cs2
}
