"obliqueshock" <- 
# compute various characteristics of an oblique shock 
# as functions of the shock angle (teta) and Froude number (F)
function(teta, Fr) {
if (any(teta<0) || any(teta>pi/2)) 
   stop("teta cannot be outside the range [0,pi/2]")
if (any(Fr<0) || any(Fr>999)) 
   stop("Fr cannot be outside the range [0,999]")
cs <- cos(teta)
sn <- sin(teta)
tn <- tan(teta)
cs2 <- cs^2
sn2 <- sn^2
Fr2sn2 <- Fr^2*sn2
G   <- sqrt(1+8*Fr2sn2)
tnphi <- 4*sn*cs*(Fr2sn2-1)/(3+4*(Fr2sn2-1)*cs2+G)
tndlt <- 2*tn/(G-1)
tndlt2 <- tndlt^2
phi   <- atan(tnphi)
dlt   <- atan(tndlt)
csdlt <- sqrt(1/(1+tndlt2))
sndlt <- sqrt(tndlt2/(1+tndlt2))
ret <- data.frame(teta=teta, phi=phi, delta=dlt, h2ph1=tn/tndlt, u2pu1=cs/csdlt, h2u2ph1u1=sn/sndlt)
attr(ret,"Fr") <- Fr
ret
}
