runuph <-
# run-up height on a dam or an obstacle corresponding to both supercritical 
# overflow and downstream thickness of a shock
function(phih,u1,h1,psi,psip,alfa,k,kp,xi,hs)
{
if (any(phih<0) || any(phih>pi/2)) 
   stop("phih cannot be outside the range [0,pi/2]")
if (any(u1<0) || any(u1>999)) 
   stop("u1 cannot be outside the range [0,999]")
if (any(h1<0) || any(h1>999)) 
   stop("h1 cannot be outside the range [0,999]")
if (any(psi<0) || any(psi>pi/2)) 
   stop("psi cannot be outside the range [0,pi/2]")
if (any(psip<(-pi/2)) || any(psip>pi/2)) 
   stop("psip cannot be outside the range [-pi/2,pi/2]")
if (!missing(alfa)) {
   if (any(alfa<0) || any(alfa>pi/2)) 
      stop("alfa cannot be outside the range [0,pi/2]")
}
if (!missing(k)) {
   if (any(k<0) || any(k>1)) 
      stop("k cannot be outside the range [0,1]")
}
if (!missing(kp)) {
   if (any(kp<0) || any(kp>0.1)) 
      stop("kp cannot be outside the range [0,0.1]")
}
if (!missing(xi)) {
   if (any(xi<0) || any(xi>999999)) 
      stop("xi cannot be outside the range [0,999999]")
}
if (!missing(hs)) {
   if (any(hs<0) || any(hs>99)) 
      stop("hs cannot be outside the range [0,999]")
}
n <- max(length(phih),length(u1),length(h1))
if (missing(kp)) kp <- rep(0,n)
if (missing(xi)) xi <- rep(0,n)
if (missing(hs)) hs <- rep(0,n)
dHslp <- rep(0,n)
dHcrv <- rep(0,n)
cspsi <- cos(psi)
phi <- phi2phi(phih=phih,psi=psi) # atan(tan(phi)*cspsi)
snphi <- sin(phi)
csphi <- cos(phi)
u1n <- u1*snphi
Fr1 <- u1/sqrt(9.82*cspsi*h1)
Fr1n <- Fr1*snphi
if (missing(k)) {
   if (missing(alfa)) stop("Either k or alfa must be specified")
   a <- alfa
   a[a>60*pi/180] <- 60*pi/180
   k <- 0.75 + 0.1*(60-a*180/pi)/30
   k[a<30*pi/180] <- 1
   if (any(a<30*pi/180)) warning("Alfa less than 30 degrees is not recommended for a dam")
}
Hcr <- h1*(1/k + 0.5*(k*Fr1n)^2 - 1.5*Fr1n^(2/3))
hcr <- h1*Fr1n^(2/3)
if (any(Fr1n<k^(-3/2))) {
   Hcr[Fr1n<k^(-3/2)] <- 0
   warning("Hcr set to zero where Fr1n < k^(-3/2)")
}
hrp <- Hcr+hcr
mxp <- mxphi(Fr1,method="approx")$phi
if (any(phi>(mxp-10*pi/180) & phi<pi/2*0.99)) {
   warning("Deflecting angle(s) are greater than recommended (phi>(mxphi-10)); phi is set to pi/2 for such angles in shock computations")
   phi[phi>(mxp-10*pi/180)] <- pi/2
}
shk <- obliquenshock(phi,Fr1)
if (any(phi<pi/2*0.99)) {
   dHslp <- sqrt(2)*tan(psip)/(2*Fr1*csphi)*xi
   dHcrv <- sqrt(2)*(u1*csphi)^2/(2*Fr1*csphi*9.82*cspsi)*kp*xi
   dHslp[phi>=pi/2*0.99] <- 0
   dHslp[phi>=pi/2*0.99] <- 0
} else {
   dHslp <- 0
   dHcrv <- 0
}
hrmx <- apply(cbind(hrp,h1*shk$h2ph1+dHslp+dHcrv),1,max) + hs
hd <- vdamheight(phi,psi,alfa,hrmx)
par <- data.frame(phih=phih,u1=u1,h1=h1,psi=psi,psip=psip,alfa=alfa,k=k,kp=kp,xi=xi,hs=hs)
ret <- data.frame(phi=phi,Fr1=Fr1,u1n=u1n,Fr1n=Fr1n,Hcr=Hcr,hcr=hcr,hrp=hrp,
       teta=shk$teta,delta=shk$delta,h2=h1*shk$h2ph1,u2=u1*shk$u2pu1,
       dHslp=dHslp,dHcrv=dHcrv,hrmx=hrmx,hd=hd)
attr(ret,"par") <- par
ret
}
