\name{mound.jump}
\alias{mound.jump}

\title{Geometry of a jet formed in the impact with a mound or a dam.}
\description{Compute the ballistic trajectory of a jet formed by the flow of an avalanche that hits a braking mound or a dam.
}

\usage{ 
mound.jump(u0,beta,h,psi,k,fph=0.004,dt=0.1)
}

\arguments{
\item{u0}{upstream velocity in metres per second.}
\item{beta}{throw angle in the sloping coordinate system aligned with the terrain.}
\item{h}{height of the mound above the snow cover in the direction normal to the terrain.}
\item{psi}{slope of the terrain.}
\item{k}{dimensionless number representing the effect of energy dissipation in the impact of the avalanche with the mound, recommended value is is \code{k} = 0.8, but \code{k} = 0.7, 0.8 and 0.9 should all be tested. The value of \code{k} is the throw velocity of the jet at the top of the dam relative to the velocity that corresponds to no loss of mechanical energy.}
\item{fph}{a coefficient with dimensions of m\eqn{^{-1}}{^(-1)} that represents the effect of air resistance on the jet, default value is 0.004 m\eqn{^{-1}}{^(-1)}.}
\item{dt}{time step in the Runge-Kutta integration, default value is 0.1 s.}
}

\value{The function returns a list of vectors including the elements \code{res}, which contains the result of the integration: \code{u1} (throw speed from the top of the mound), \code{x2} (slope distance to the landing point of the jet), \code{x2cpsi} (map distance to the landing point of the jet), \code{u2} (speed of the jet at the landing point) and \code{betalnd} (angle of the jet at the landing point with respect of the terrain); \code{par}, which contains the arguments of the call to the function; and \code{x}, \code{y} and \code{u}, which are arrays of coordinates and speed along the computed trajectory.
}
\author{Tomas Johannesson}

\examples{
\dontrun{
mound.jump(32,55*pi/180,10,11*pi/180,k=0.8)$res
}
}

\note{The angles \code{beta} and \code{psi} are given in radians.

The computation of the ballistic jet is carried out in a sloping coordinate system that is aligned with the terrain in the neighbourhood of the mound or dam. This must be taken into consideration if one wishes to draw the geometry of the jet using the returned arrays \code{x} and \code{y} (\code{x} represents distance from the mound top along the sloping terrain and \code{y} is height above the terrain/snow cover in the direction normal to the terrain).

The height of the mound is defined as the height above the snow cover. The snow cover is for simplicity assumed to be uniform in thickness all along the terrain down to the landing point of the jet.
}

\seealso{\code{\link{viadam.runge.kutta}}.}

\keyword{math}
