\name{obliquenshock}
\alias{obliquenshock}

\title{Approximate characteristics of an oblique shock}
\description{Computes the shock angle, shock thickness, downstream velocity and downstream momentum flux for an oblique shock as functions of deflecting angle and Froude number using an approximation based on the flow against a normal shock with the speed of the normal component of the oblique flow.
}

\usage{ 
obliquenshock(phi,Fr)
}

\arguments{
\item{phi}{deflecting angle with respect to the direction of steepest decent in a sloping coordinate system aligned with the terrain.}
\item{Fr}{Froude number.}
}

\value{\code{obliquenshock} returns a dataframe containing the variables \code{phi} (deflecting angle), \code{delta} (difference between \code{teta} and \code{phi}, \emph{i.e.}\ width of the stream along the deflecting wall), \code{teta} (shock angle), \code{h2ph1} (relative change in flow depth across the shock), \code{u2pu1} (relative change in flow speed across the shock) and \code{h2u2ph1u1} (relative change in momentum flux across the shock). These variables have the same number of elements as \code{teta} or \code{Fr}. The Froude number and the Froude number normal to the wall are returned as the attributes \code{Fr} and \code{Fp} of the list.
}
\author{Tomas Johannesson}

\examples{
\dontrun{
obliquenshock(15*pi/180,7)
}
}

\note{The angle \code{phi} is given in radians and so are all angles that are returned by the function.

This function computes the characteristics of a weak oblique shock. The corresponding strong oblique shock with a (much) larger value of the shock angle \code{teta} is eliminated by the approximations used in the derivations of the formulas used. The function \code{\link{obliqueshock}} may be used to obtain both types of the oblique shock.

The approximations used in this function provide good accuracy for \code{Fr}>2.5 and deflecting angles \code{phi} somewhat below the maximum deflecting angle which separates the weak and strong shocks for a particular value of the Froude number \code{Fr}.
}

\seealso{\code{\link{obliqueshock}} and \code{\link{mxphi}}.}

\keyword{math}
